#!/bin/bash

# ============================================================================
# Process MODIS granule CREFL - Land surface corrected reflectance
# 
# This script is a wrapper script for the CREFL algorithm. MODIS  L1B data can
# be procesed through this script. The script takes all the L1B files
# (different resolutions) as input, as well as the CREFL output file names. 
# 
# Note: If the output files already exist, the script will not process the 
#       input L1B data.
# 
# Authors: Liam.Gumley@ssec.wisc.edu, Willem.Marais@ssec.wisc.edu 
# Date:
# 07/22/2011
# ============================================================================

# Check for MIPS_HOME environment variable
# if [ -z "$MIPS_HOME" ]; then
#   echo "Environment variable MIPS_HOME is not set"
#   exit 1
# fi

if [ $# -ne 4 ]; then
    echo "(ERROR) Usage:"
    echo "    "$(basename $0)" <L1B 1KM> <L1B QKM> <CREFL 1KM> <CREFL QKM>"
    exit 1
fi

# Get arguments
fil_1km=$1
fil_qkm=$2
ref_1km=$3
ref_qkm=$4

# If the CREFL product files already exists, do not reprocess the data
if [ -e $ref_1km ] && [ -e $ref_qkm ]; then
    exit 0
fi

# Create soft links to standard filenames expected by crefl
ln -s $fil_1km MOD021KM.tmp.hdf
ln -s $fil_qkm MOD02QKM.tmp.hdf

# Set up crefl environment
export ANCPATH=$MIPS_HOME/bin

# Run corrected reflectance code 1KM
echo
echo "(Creating 1KM corrected reflectance in "$ref_1km")"
/data/willemm/ForLiam/programs/mersi_crefl.1.4.2 -p -v -f -1km MOD02QKM.tmp.hdf MOD021KM.tmp.hdf -of=$ref_1km -bands=1,2,3,4,5,6,7

if [ $? -ne 0 ]; then
    echo "(ERROR)[E1] CREFL failed to process 1KM L1B data"
    exit 1
fi

# Run corrected reflectance code QKM
echo
echo "(Creating QKM corrected reflectance in "$ref_qkm")"
/data/willemm/ForLiam/programs/mersi_crefl.1.4.2 -p -v -f MOD02QKM.tmp.hdf MOD021KM.tmp.hdf -of=$ref_qkm -bands=1,2,3,4,5,6,7

if [ $? -ne 0 ]; then
    echo "(ERROR)[E3] CREFL failed to process 250M L1B data"
    exit 1
fi

# Clean up
rm -f MOD02QKM.tmp.hdf MOD021KM.tmp.hdf
rm -f idl_output.txt idlsave.pro runidl

